@@ -19,16 +19,16 @@ use std::collections::HashSet;
 //  # duplicate_vertices
 //  # unused_vertices
 
-static EXTENSION_FIXED_NAMES: [&str; 9] = [
+static EXTENSION_FIXED_NAMES: [&str; 6] = [
     "type",
     "name",
     "uri",
     "version",
     "versionCityJSON",
     "description",
-    "extraAttributes",
-    "extraCityObjects",
-    "extraRootProperties",
+    // "extraAttributes",
+    // "extraCityObjects",
+    // "extraRootProperties",
 ];
 
 pub static CITYJSON_VERSIONS: [&str; 2] = ["1.0.3", "1.1.0"];
@@ -449,15 +449,11 @@ impl CJValidator {
                 let thechildrenkeys = co.get("children").unwrap().as_array().unwrap();
                 for ckey in thechildrenkeys {
                     if !cos.contains_key(ckey.as_str().unwrap()) {
-                        let s =
-                            format!("CityObject #{} doesn't exit [referenced by #{}]", ckey, key);
-                        ls_errors.push(s);
-                    }
-                }
-                for ckey in thechildrenkeys {
-                    if !cos.contains_key(ckey.as_str().unwrap()) {
-                        let s =
-                            format!("CityObject #{} doesn't exit (referenced by #{}", ckey, key);
+                        let s = format!(
+                            "CityObject #{} doesn't exist (referenced by #{})",
+                            ckey.as_str().unwrap(),
+                            key
+                        );
                         ls_errors.push(s);
                     } else {
                         if (!cos
@@ -478,8 +474,9 @@ impl CJValidator {
                                 .contains(&json!(key)))
                         {
                             let s = format!(
-                                "CityObject #{} doesn't reference correct parent ({})",
-                                ckey, key
+                                "CityObject #{} doesn't reference correct parent (#{})",
+                                ckey.as_str().unwrap(),
+                                key
                             );
                             ls_errors.push(s);
                         }
@@ -495,8 +492,9 @@ impl CJValidator {
                 for pkey in theparentkeys {
                     if !cos.contains_key(pkey.as_str().unwrap()) {
                         let s = format!(
-                            "CityObject #{} is an orphan [parent #{} doesn't exist]",
-                            key, pkey
+                            "CityObject #{} is an orphan (parent #{} doesn't exist)",
+                            key,
+                            pkey.as_str().unwrap()
                         );
                         ls_errors.push(s);
                     }
